@@ -1,4 +1,4 @@
-# coding=utf-8
+# -*- coding: utf-8 -*-
 """
 用于管理缓存的配置数据
 使用前必须先调用 init() 。
@@ -16,8 +16,16 @@ logger = logging.getLogger(__name__)
 __all__ = ['set', 'get', 'copy', 'update', 'settings']
 
 settings = {
-    'SERVER': {'HQ': HQ_HOSTS, 'EX': EX_HOSTS, 'GP': GP_HOSTS},
-    'BESTIP': {'HQ': '', 'EX': '', 'GP': ''},
+    'SERVER': {
+        'HQ': HQ_HOSTS,
+        'EX': EX_HOSTS,
+        'GP': GP_HOSTS
+    },
+    'BESTIP': {
+        'HQ': '',
+        'EX': '',
+        'GP': ''
+    },
     'TDXDIR': 'C:/new_tdx',
 }
 
